\name{Trend}
\alias{Trend}
\title{
Computes the trend of the ensemble mean.
}
\description{
Computes the trend along the forecast time of the ensemble mean by least square fitting, and the associated error interval.\cr
Trend() also provides the time series of the detrended ensemble mean forecasts.\cr
The confidence interval relies on a student-T distribution.
}
\usage{
Trend(ens, interval = 1, siglev = 0.95, conf = TRUE)
}
\arguments{
  \item{ens}{
M by N matrix of M forecasts from N ensemble members.
  }
  
  \item{interval}{
Number of months/years between 2 points along posTR dimension.\cr
Default = 1.\cr
The trend would be provided in number of units per month or year.
  }
  \item{siglev}{
Confidence level for the computation of confidence interval. 0.95 by default.
  }
  \item{conf}{
Whether to compute the confidence levels or not. TRUE by default.
  }
}
\value{
  \item{$trend}{
The intercept and slope coefficients for the least squares fitting of the trend, 
  }
\item{$conf.int}{corresponding to the limits of the \code{siglev}\% confidence interval (only present if \code{conf = TRUE}) for the slope coefficient.}  
  \item{$detrended}{
Same dimensions as var with linearly detrended var along the posTR dimension.
  }
}
\examples{
ens <- matrix(rnorm(500), c(100,5))    
#Add a trend to the first ensemble member
ens[,1] <- ens[,1]+(seq(1,100,1)*5)
ens.trend <- Trend(ens)


\author{
History:\cr
0.1  -  2011-05  (V. Guemas, \email{virginie.guemas at ic3.cat})  -  Original code\cr
1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens at ic3.cat})  -  Formatting to CRAN
}
\keyword{datagen}
